@@ -16,7 +16,7 @@ class GeneratorConfig(object):
             line = '\n\tpublic static $SUPPORT_{}_PROTOCOL = {};'.format(format_string.upper(), support)
             content += line
         content = CONTENT.format(content)
-        model.add_file(filename, content)
+        model.add_file(None, filename, content)
 
 
 CONTENT = '''<?php
