@@ -29,10 +29,14 @@ class DataWrapper(object):
         return object.__getattribute__(self, 'instance').__getattribute__(name)
 
     def __eq__(self, rhs):
-        return rhs.name is not None and self.name == rhs.name
+        if rhs is None:
+            return object.__getattribute__(self, 'instance') is None
+        return rhs is not None and rhs.name is not None and self.name == rhs.name
 
     def __ne__(self, rhs):
-        return rhs.name is None or self.name != rhs.name
+        if rhs is None:
+            return object.__getattribute__(self, 'instance') is not None
+        return rhs is not None and rhs.name is None or self.name != rhs.name
 
     def __hash__(self):
         return hash(self.name)
@@ -78,7 +82,7 @@ class SerializerXml(object):
         self.node = node
 
     def serialize(self, obj, key, default_value=None):
-        if isinstance(obj, DataWrapper):
+        if isinstance(obj, DataWrapper) and obj is not None:
             self.serialize_attr(obj.name, key, default_value)
         elif isinstance(obj, IntrusivePtr):
             child = self.add_child(key)
